Documentation
¶
Index ¶
- Variables
- func AddAdminuserHook(hookPoint boil.HookPoint, adminuserHook AdminuserHook)
- func AddAdminuserssotokenHook(hookPoint boil.HookPoint, adminuserssotokenHook AdminuserssotokenHook)
- func AddAuditlogHook(hookPoint boil.HookPoint, auditlogHook AuditlogHook)
- func AddRevokedtokenHook(hookPoint boil.HookPoint, revokedtokenHook RevokedtokenHook)
- func AdminuserExists(ctx context.Context, exec boil.ContextExecutor, iD uint) (bool, error)
- func Adminusers(mods ...qm.QueryMod) adminuserQuery
- func AdminuserssotokenExists(ctx context.Context, exec boil.ContextExecutor, iD uint) (bool, error)
- func Adminuserssotokens(mods ...qm.QueryMod) adminuserssotokenQuery
- func AuditlogExists(ctx context.Context, exec boil.ContextExecutor, iD uint) (bool, error)
- func Auditlogs(mods ...qm.QueryMod) auditlogQuery
- func NewQuery(mods ...qm.QueryMod) *queries.Query
- func RevokedtokenExists(ctx context.Context, exec boil.ContextExecutor, iD uint) (bool, error)
- func Revokedtokens(mods ...qm.QueryMod) revokedtokenQuery
- type Adminuser
- func (o *Adminuser) Delete(ctx context.Context, exec boil.ContextExecutor) (int64, error)
- func (o *Adminuser) Exists(ctx context.Context, exec boil.ContextExecutor) (bool, error)
- func (o *Adminuser) Insert(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) error
- func (o *Adminuser) Reload(ctx context.Context, exec boil.ContextExecutor) error
- func (o *Adminuser) Update(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) (int64, error)
- func (o *Adminuser) Upsert(ctx context.Context, exec boil.ContextExecutor, ...) error
- type AdminuserHook
- type AdminuserSlice
- type Adminuserssotoken
- func (o *Adminuserssotoken) Delete(ctx context.Context, exec boil.ContextExecutor) (int64, error)
- func (o *Adminuserssotoken) Exists(ctx context.Context, exec boil.ContextExecutor) (bool, error)
- func (o *Adminuserssotoken) Insert(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) error
- func (o *Adminuserssotoken) Reload(ctx context.Context, exec boil.ContextExecutor) error
- func (o *Adminuserssotoken) Update(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) (int64, error)
- func (o *Adminuserssotoken) Upsert(ctx context.Context, exec boil.ContextExecutor, ...) error
- type AdminuserssotokenHook
- type AdminuserssotokenSlice
- func (o AdminuserssotokenSlice) DeleteAll(ctx context.Context, exec boil.ContextExecutor) (int64, error)
- func (o *AdminuserssotokenSlice) ReloadAll(ctx context.Context, exec boil.ContextExecutor) error
- func (o AdminuserssotokenSlice) UpdateAll(ctx context.Context, exec boil.ContextExecutor, cols M) (int64, error)
- type Auditlog
- func (o *Auditlog) Delete(ctx context.Context, exec boil.ContextExecutor) (int64, error)
- func (o *Auditlog) Exists(ctx context.Context, exec boil.ContextExecutor) (bool, error)
- func (o *Auditlog) Insert(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) error
- func (o *Auditlog) Reload(ctx context.Context, exec boil.ContextExecutor) error
- func (o *Auditlog) Update(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) (int64, error)
- func (o *Auditlog) Upsert(ctx context.Context, exec boil.ContextExecutor, ...) error
- type AuditlogHook
- type AuditlogSlice
- type M
- type Revokedtoken
- func (o *Revokedtoken) Delete(ctx context.Context, exec boil.ContextExecutor) (int64, error)
- func (o *Revokedtoken) Exists(ctx context.Context, exec boil.ContextExecutor) (bool, error)
- func (o *Revokedtoken) Insert(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) error
- func (o *Revokedtoken) Reload(ctx context.Context, exec boil.ContextExecutor) error
- func (o *Revokedtoken) Update(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) (int64, error)
- func (o *Revokedtoken) Upsert(ctx context.Context, exec boil.ContextExecutor, ...) error
- type RevokedtokenHook
- type RevokedtokenSlice
Constants ¶
This section is empty.
Variables ¶
var AdminuserColumns = struct { ID string Email string Password string Salt string CreatedAt string UpdatedAt string }{ ID: "id", Email: "email", Password: "password", Salt: "salt", CreatedAt: "createdAt", UpdatedAt: "updatedAt", }
var AdminuserRels = struct {
}{}
AdminuserRels is where relationship names are stored.
var AdminuserTableColumns = struct { ID string Email string Password string Salt string CreatedAt string UpdatedAt string }{ ID: "adminusers.id", Email: "adminusers.email", Password: "adminusers.password", Salt: "adminusers.salt", CreatedAt: "adminusers.createdAt", UpdatedAt: "adminusers.updatedAt", }
var AdminuserWhere = struct { ID whereHelperuint Email whereHelperstring Password whereHelpernull_String Salt whereHelpernull_String CreatedAt whereHelpertime_Time UpdatedAt whereHelpertime_Time }{ ID: whereHelperuint{/* contains filtered or unexported fields */}, Email: whereHelperstring{/* contains filtered or unexported fields */}, Password: whereHelpernull_String{/* contains filtered or unexported fields */}, Salt: whereHelpernull_String{/* contains filtered or unexported fields */}, CreatedAt: whereHelpertime_Time{/* contains filtered or unexported fields */}, UpdatedAt: whereHelpertime_Time{/* contains filtered or unexported fields */}, }
var AdminuserssotokenColumns = struct { ID string UserId string ClientId string Provider string AuthType string AccessToken string ExpiryDate string IdToken string RefreshToken string TokenType string CreatedAt string UpdatedAt string }{ ID: "id", UserId: "userId", ClientId: "clientId", Provider: "provider", AuthType: "authType", AccessToken: "accessToken", ExpiryDate: "expiryDate", IdToken: "idToken", RefreshToken: "refreshToken", TokenType: "tokenType", CreatedAt: "createdAt", UpdatedAt: "updatedAt", }
var AdminuserssotokenRels = struct {
}{}
AdminuserssotokenRels is where relationship names are stored.
var AdminuserssotokenTableColumns = struct { ID string UserId string ClientId string Provider string AuthType string AccessToken string ExpiryDate string IdToken string RefreshToken string TokenType string CreatedAt string UpdatedAt string }{ ID: "adminuserssotokens.id", UserId: "adminuserssotokens.userId", ClientId: "adminuserssotokens.clientId", Provider: "adminuserssotokens.provider", AuthType: "adminuserssotokens.authType", AccessToken: "adminuserssotokens.accessToken", ExpiryDate: "adminuserssotokens.expiryDate", IdToken: "adminuserssotokens.idToken", RefreshToken: "adminuserssotokens.refreshToken", TokenType: "adminuserssotokens.tokenType", CreatedAt: "adminuserssotokens.createdAt", UpdatedAt: "adminuserssotokens.updatedAt", }
var AdminuserssotokenWhere = struct { ID whereHelperuint UserId whereHelperstring ClientId whereHelperstring Provider whereHelperstring AuthType whereHelperstring AccessToken whereHelperstring ExpiryDate whereHelperint64 IdToken whereHelperstring RefreshToken whereHelpernull_String TokenType whereHelperstring CreatedAt whereHelpertime_Time UpdatedAt whereHelpertime_Time }{ ID: whereHelperuint{/* contains filtered or unexported fields */}, UserId: whereHelperstring{/* contains filtered or unexported fields */}, ClientId: whereHelperstring{/* contains filtered or unexported fields */}, Provider: whereHelperstring{/* contains filtered or unexported fields */}, AuthType: whereHelperstring{/* contains filtered or unexported fields */}, AccessToken: whereHelperstring{/* contains filtered or unexported fields */}, ExpiryDate: whereHelperint64{/* contains filtered or unexported fields */}, IdToken: whereHelperstring{/* contains filtered or unexported fields */}, RefreshToken: whereHelpernull_String{/* contains filtered or unexported fields */}, TokenType: whereHelperstring{/* contains filtered or unexported fields */}, CreatedAt: whereHelpertime_Time{/* contains filtered or unexported fields */}, UpdatedAt: whereHelpertime_Time{/* contains filtered or unexported fields */}, }
var AuditlogColumns = struct { ID string RequestMethod string RequestUri string SourceIp string UserId string RequestBody string StatusCode string CreatedAt string UpdatedAt string }{ ID: "id", RequestMethod: "requestMethod", RequestUri: "requestUri", SourceIp: "sourceIp", UserId: "userId", RequestBody: "requestBody", StatusCode: "statusCode", CreatedAt: "createdAt", UpdatedAt: "updatedAt", }
var AuditlogRels = struct {
}{}
AuditlogRels is where relationship names are stored.
var AuditlogTableColumns = struct { ID string RequestMethod string RequestUri string SourceIp string UserId string RequestBody string StatusCode string CreatedAt string UpdatedAt string }{ ID: "auditlogs.id", RequestMethod: "auditlogs.requestMethod", RequestUri: "auditlogs.requestUri", SourceIp: "auditlogs.sourceIp", UserId: "auditlogs.userId", RequestBody: "auditlogs.requestBody", StatusCode: "auditlogs.statusCode", CreatedAt: "auditlogs.createdAt", UpdatedAt: "auditlogs.updatedAt", }
var AuditlogWhere = struct { ID whereHelperuint RequestMethod whereHelpernull_String RequestUri whereHelpernull_String SourceIp whereHelpernull_String UserId whereHelpernull_String RequestBody whereHelpernull_String StatusCode whereHelpernull_Uint CreatedAt whereHelpertime_Time UpdatedAt whereHelpertime_Time }{ ID: whereHelperuint{/* contains filtered or unexported fields */}, RequestMethod: whereHelpernull_String{/* contains filtered or unexported fields */}, RequestUri: whereHelpernull_String{/* contains filtered or unexported fields */}, SourceIp: whereHelpernull_String{/* contains filtered or unexported fields */}, UserId: whereHelpernull_String{/* contains filtered or unexported fields */}, RequestBody: whereHelpernull_String{/* contains filtered or unexported fields */}, StatusCode: whereHelpernull_Uint{/* contains filtered or unexported fields */}, CreatedAt: whereHelpertime_Time{/* contains filtered or unexported fields */}, UpdatedAt: whereHelpertime_Time{/* contains filtered or unexported fields */}, }
var ErrSyncFail = errors.New("models: failed to synchronize data after insert")
ErrSyncFail occurs during insert when the record could not be retrieved in order to populate default value information. This usually happens when LastInsertId fails or there was a primary key configuration that was not resolvable.
var RevokedtokenColumns = struct { ID string Token string RevokedAt string CreatedAt string UpdatedAt string }{ ID: "id", Token: "token", RevokedAt: "revokedAt", CreatedAt: "createdAt", UpdatedAt: "updatedAt", }
var RevokedtokenRels = struct {
}{}
RevokedtokenRels is where relationship names are stored.
var RevokedtokenTableColumns = struct { ID string Token string RevokedAt string CreatedAt string UpdatedAt string }{ ID: "revokedtokens.id", Token: "revokedtokens.token", RevokedAt: "revokedtokens.revokedAt", CreatedAt: "revokedtokens.createdAt", UpdatedAt: "revokedtokens.updatedAt", }
var RevokedtokenWhere = struct { ID whereHelperuint Token whereHelperstring RevokedAt whereHelpertime_Time CreatedAt whereHelpertime_Time UpdatedAt whereHelpertime_Time }{ ID: whereHelperuint{/* contains filtered or unexported fields */}, Token: whereHelperstring{/* contains filtered or unexported fields */}, RevokedAt: whereHelpertime_Time{/* contains filtered or unexported fields */}, CreatedAt: whereHelpertime_Time{/* contains filtered or unexported fields */}, UpdatedAt: whereHelpertime_Time{/* contains filtered or unexported fields */}, }
var TableNames = struct { Adminusers string Adminuserssotokens string Auditlogs string Revokedtokens string }{ Adminusers: "adminusers", Adminuserssotokens: "adminuserssotokens", Auditlogs: "auditlogs", Revokedtokens: "revokedtokens", }
var ViewNames = struct {
}{}
Functions ¶
func AddAdminuserHook ¶
func AddAdminuserHook(hookPoint boil.HookPoint, adminuserHook AdminuserHook)
AddAdminuserHook registers your hook function for all future operations.
func AddAdminuserssotokenHook ¶
func AddAdminuserssotokenHook(hookPoint boil.HookPoint, adminuserssotokenHook AdminuserssotokenHook)
AddAdminuserssotokenHook registers your hook function for all future operations.
func AddAuditlogHook ¶
func AddAuditlogHook(hookPoint boil.HookPoint, auditlogHook AuditlogHook)
AddAuditlogHook registers your hook function for all future operations.
func AddRevokedtokenHook ¶
func AddRevokedtokenHook(hookPoint boil.HookPoint, revokedtokenHook RevokedtokenHook)
AddRevokedtokenHook registers your hook function for all future operations.
func AdminuserExists ¶
AdminuserExists checks if the Adminuser row exists.
func Adminusers ¶
Adminusers retrieves all the records using an executor.
func AdminuserssotokenExists ¶
AdminuserssotokenExists checks if the Adminuserssotoken row exists.
func Adminuserssotokens ¶
Adminuserssotokens retrieves all the records using an executor.
func AuditlogExists ¶
AuditlogExists checks if the Auditlog row exists.
func RevokedtokenExists ¶
RevokedtokenExists checks if the Revokedtoken row exists.
func Revokedtokens ¶
Revokedtokens retrieves all the records using an executor.
Types ¶
type Adminuser ¶
type Adminuser struct {
ID uint `boil:"id" json:"id" toml:"id" yaml:"id"`
Email string `boil:"email" json:"email" toml:"email" yaml:"email"`
Password null.String `boil:"password" json:"password,omitempty" toml:"password" yaml:"password,omitempty"`
Salt null.String `boil:"salt" json:"salt,omitempty" toml:"salt" yaml:"salt,omitempty"`
CreatedAt time.Time `boil:"createdAt" json:"createdAt" toml:"createdAt" yaml:"createdAt"`
UpdatedAt time.Time `boil:"updatedAt" json:"updatedAt" toml:"updatedAt" yaml:"updatedAt"`
R *adminuserR `boil:"-" json:"-" toml:"-" yaml:"-"`
L adminuserL `boil:"-" json:"-" toml:"-" yaml:"-"`
}
Adminuser is an object representing the database table.
func FindAdminuser ¶
func FindAdminuser(ctx context.Context, exec boil.ContextExecutor, iD uint, selectCols ...string) (*Adminuser, error)
FindAdminuser retrieves a single record by ID with an executor. If selectCols is empty Find will return all columns.
func (*Adminuser) Delete ¶
Delete deletes a single Adminuser record with an executor. Delete will match against the primary key column to find the record to delete.
func (*Adminuser) Insert ¶
func (o *Adminuser) Insert(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) error
Insert a single record using an executor. See boil.Columns.InsertColumnSet documentation to understand column list inference for inserts.
func (*Adminuser) Reload ¶
Reload refetches the object from the database using the primary keys with an executor.
func (*Adminuser) Update ¶
func (o *Adminuser) Update(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) (int64, error)
Update uses an executor to update the Adminuser. See boil.Columns.UpdateColumnSet documentation to understand column list inference for updates. Update does not automatically update the record in case of default values. Use .Reload() to refresh the records.
func (*Adminuser) Upsert ¶
func (o *Adminuser) Upsert(ctx context.Context, exec boil.ContextExecutor, updateColumns, insertColumns boil.Columns) error
Upsert attempts an insert using an executor, and does an update or ignore on conflict. See boil.Columns documentation for how to properly use updateColumns and insertColumns.
type AdminuserHook ¶
AdminuserHook is the signature for custom Adminuser hook methods
type AdminuserSlice ¶
type AdminuserSlice []*Adminuser
AdminuserSlice is an alias for a slice of pointers to Adminuser. This should almost always be used instead of []Adminuser.
func (AdminuserSlice) DeleteAll ¶
func (o AdminuserSlice) DeleteAll(ctx context.Context, exec boil.ContextExecutor) (int64, error)
DeleteAll deletes all rows in the slice, using an executor.
func (*AdminuserSlice) ReloadAll ¶
func (o *AdminuserSlice) ReloadAll(ctx context.Context, exec boil.ContextExecutor) error
ReloadAll refetches every row with matching primary key column values and overwrites the original object slice with the newly updated slice.
func (AdminuserSlice) UpdateAll ¶
func (o AdminuserSlice) UpdateAll(ctx context.Context, exec boil.ContextExecutor, cols M) (int64, error)
UpdateAll updates all rows with the specified column values, using an executor.
type Adminuserssotoken ¶
type Adminuserssotoken struct {
ID uint `boil:"id" json:"id" toml:"id" yaml:"id"`
UserId string `boil:"userId" json:"userId" toml:"userId" yaml:"userId"`
ClientId string `boil:"clientId" json:"clientId" toml:"clientId" yaml:"clientId"`
Provider string `boil:"provider" json:"provider" toml:"provider" yaml:"provider"`
AuthType string `boil:"authType" json:"authType" toml:"authType" yaml:"authType"`
AccessToken string `boil:"accessToken" json:"accessToken" toml:"accessToken" yaml:"accessToken"`
ExpiryDate int64 `boil:"expiryDate" json:"expiryDate" toml:"expiryDate" yaml:"expiryDate"`
IdToken string `boil:"idToken" json:"idToken" toml:"idToken" yaml:"idToken"`
RefreshToken null.String `boil:"refreshToken" json:"refreshToken,omitempty" toml:"refreshToken" yaml:"refreshToken,omitempty"`
TokenType string `boil:"tokenType" json:"tokenType" toml:"tokenType" yaml:"tokenType"`
CreatedAt time.Time `boil:"createdAt" json:"createdAt" toml:"createdAt" yaml:"createdAt"`
UpdatedAt time.Time `boil:"updatedAt" json:"updatedAt" toml:"updatedAt" yaml:"updatedAt"`
R *adminuserssotokenR `boil:"-" json:"-" toml:"-" yaml:"-"`
L adminuserssotokenL `boil:"-" json:"-" toml:"-" yaml:"-"`
}
Adminuserssotoken is an object representing the database table.
func FindAdminuserssotoken ¶
func FindAdminuserssotoken(ctx context.Context, exec boil.ContextExecutor, iD uint, selectCols ...string) (*Adminuserssotoken, error)
FindAdminuserssotoken retrieves a single record by ID with an executor. If selectCols is empty Find will return all columns.
func (*Adminuserssotoken) Delete ¶
func (o *Adminuserssotoken) Delete(ctx context.Context, exec boil.ContextExecutor) (int64, error)
Delete deletes a single Adminuserssotoken record with an executor. Delete will match against the primary key column to find the record to delete.
func (*Adminuserssotoken) Exists ¶
func (o *Adminuserssotoken) Exists(ctx context.Context, exec boil.ContextExecutor) (bool, error)
Exists checks if the Adminuserssotoken row exists.
func (*Adminuserssotoken) Insert ¶
func (o *Adminuserssotoken) Insert(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) error
Insert a single record using an executor. See boil.Columns.InsertColumnSet documentation to understand column list inference for inserts.
func (*Adminuserssotoken) Reload ¶
func (o *Adminuserssotoken) Reload(ctx context.Context, exec boil.ContextExecutor) error
Reload refetches the object from the database using the primary keys with an executor.
func (*Adminuserssotoken) Update ¶
func (o *Adminuserssotoken) Update(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) (int64, error)
Update uses an executor to update the Adminuserssotoken. See boil.Columns.UpdateColumnSet documentation to understand column list inference for updates. Update does not automatically update the record in case of default values. Use .Reload() to refresh the records.
func (*Adminuserssotoken) Upsert ¶
func (o *Adminuserssotoken) Upsert(ctx context.Context, exec boil.ContextExecutor, updateColumns, insertColumns boil.Columns) error
Upsert attempts an insert using an executor, and does an update or ignore on conflict. See boil.Columns documentation for how to properly use updateColumns and insertColumns.
type AdminuserssotokenHook ¶
type AdminuserssotokenHook func(context.Context, boil.ContextExecutor, *Adminuserssotoken) error
AdminuserssotokenHook is the signature for custom Adminuserssotoken hook methods
type AdminuserssotokenSlice ¶
type AdminuserssotokenSlice []*Adminuserssotoken
AdminuserssotokenSlice is an alias for a slice of pointers to Adminuserssotoken. This should almost always be used instead of []Adminuserssotoken.
func (AdminuserssotokenSlice) DeleteAll ¶
func (o AdminuserssotokenSlice) DeleteAll(ctx context.Context, exec boil.ContextExecutor) (int64, error)
DeleteAll deletes all rows in the slice, using an executor.
func (*AdminuserssotokenSlice) ReloadAll ¶
func (o *AdminuserssotokenSlice) ReloadAll(ctx context.Context, exec boil.ContextExecutor) error
ReloadAll refetches every row with matching primary key column values and overwrites the original object slice with the newly updated slice.
func (AdminuserssotokenSlice) UpdateAll ¶
func (o AdminuserssotokenSlice) UpdateAll(ctx context.Context, exec boil.ContextExecutor, cols M) (int64, error)
UpdateAll updates all rows with the specified column values, using an executor.
type Auditlog ¶
type Auditlog struct {
ID uint `boil:"id" json:"id" toml:"id" yaml:"id"`
RequestMethod null.String `boil:"requestMethod" json:"requestMethod,omitempty" toml:"requestMethod" yaml:"requestMethod,omitempty"`
RequestUri null.String `boil:"requestUri" json:"requestUri,omitempty" toml:"requestUri" yaml:"requestUri,omitempty"`
SourceIp null.String `boil:"sourceIp" json:"sourceIp,omitempty" toml:"sourceIp" yaml:"sourceIp,omitempty"`
UserId null.String `boil:"userId" json:"userId,omitempty" toml:"userId" yaml:"userId,omitempty"`
RequestBody null.String `boil:"requestBody" json:"requestBody,omitempty" toml:"requestBody" yaml:"requestBody,omitempty"`
StatusCode null.Uint `boil:"statusCode" json:"statusCode,omitempty" toml:"statusCode" yaml:"statusCode,omitempty"`
CreatedAt time.Time `boil:"createdAt" json:"createdAt" toml:"createdAt" yaml:"createdAt"`
UpdatedAt time.Time `boil:"updatedAt" json:"updatedAt" toml:"updatedAt" yaml:"updatedAt"`
R *auditlogR `boil:"-" json:"-" toml:"-" yaml:"-"`
L auditlogL `boil:"-" json:"-" toml:"-" yaml:"-"`
}
Auditlog is an object representing the database table.
func FindAuditlog ¶
func FindAuditlog(ctx context.Context, exec boil.ContextExecutor, iD uint, selectCols ...string) (*Auditlog, error)
FindAuditlog retrieves a single record by ID with an executor. If selectCols is empty Find will return all columns.
func (*Auditlog) Delete ¶
Delete deletes a single Auditlog record with an executor. Delete will match against the primary key column to find the record to delete.
func (*Auditlog) Insert ¶
func (o *Auditlog) Insert(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) error
Insert a single record using an executor. See boil.Columns.InsertColumnSet documentation to understand column list inference for inserts.
func (*Auditlog) Reload ¶
Reload refetches the object from the database using the primary keys with an executor.
func (*Auditlog) Update ¶
func (o *Auditlog) Update(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) (int64, error)
Update uses an executor to update the Auditlog. See boil.Columns.UpdateColumnSet documentation to understand column list inference for updates. Update does not automatically update the record in case of default values. Use .Reload() to refresh the records.
func (*Auditlog) Upsert ¶
func (o *Auditlog) Upsert(ctx context.Context, exec boil.ContextExecutor, updateColumns, insertColumns boil.Columns) error
Upsert attempts an insert using an executor, and does an update or ignore on conflict. See boil.Columns documentation for how to properly use updateColumns and insertColumns.
type AuditlogHook ¶
AuditlogHook is the signature for custom Auditlog hook methods
type AuditlogSlice ¶
type AuditlogSlice []*Auditlog
AuditlogSlice is an alias for a slice of pointers to Auditlog. This should almost always be used instead of []Auditlog.
func (AuditlogSlice) DeleteAll ¶
func (o AuditlogSlice) DeleteAll(ctx context.Context, exec boil.ContextExecutor) (int64, error)
DeleteAll deletes all rows in the slice, using an executor.
func (*AuditlogSlice) ReloadAll ¶
func (o *AuditlogSlice) ReloadAll(ctx context.Context, exec boil.ContextExecutor) error
ReloadAll refetches every row with matching primary key column values and overwrites the original object slice with the newly updated slice.
func (AuditlogSlice) UpdateAll ¶
func (o AuditlogSlice) UpdateAll(ctx context.Context, exec boil.ContextExecutor, cols M) (int64, error)
UpdateAll updates all rows with the specified column values, using an executor.
type M ¶
type M map[string]interface{}
M type is for providing columns and column values to UpdateAll.
type Revokedtoken ¶
type Revokedtoken struct {
ID uint `boil:"id" json:"id" toml:"id" yaml:"id"`
Token string `boil:"token" json:"token" toml:"token" yaml:"token"`
RevokedAt time.Time `boil:"revokedAt" json:"revokedAt" toml:"revokedAt" yaml:"revokedAt"`
CreatedAt time.Time `boil:"createdAt" json:"createdAt" toml:"createdAt" yaml:"createdAt"`
UpdatedAt time.Time `boil:"updatedAt" json:"updatedAt" toml:"updatedAt" yaml:"updatedAt"`
R *revokedtokenR `boil:"-" json:"-" toml:"-" yaml:"-"`
L revokedtokenL `boil:"-" json:"-" toml:"-" yaml:"-"`
}
Revokedtoken is an object representing the database table.
func FindRevokedtoken ¶
func FindRevokedtoken(ctx context.Context, exec boil.ContextExecutor, iD uint, selectCols ...string) (*Revokedtoken, error)
FindRevokedtoken retrieves a single record by ID with an executor. If selectCols is empty Find will return all columns.
func (*Revokedtoken) Delete ¶
func (o *Revokedtoken) Delete(ctx context.Context, exec boil.ContextExecutor) (int64, error)
Delete deletes a single Revokedtoken record with an executor. Delete will match against the primary key column to find the record to delete.
func (*Revokedtoken) Exists ¶
func (o *Revokedtoken) Exists(ctx context.Context, exec boil.ContextExecutor) (bool, error)
Exists checks if the Revokedtoken row exists.
func (*Revokedtoken) Insert ¶
func (o *Revokedtoken) Insert(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) error
Insert a single record using an executor. See boil.Columns.InsertColumnSet documentation to understand column list inference for inserts.
func (*Revokedtoken) Reload ¶
func (o *Revokedtoken) Reload(ctx context.Context, exec boil.ContextExecutor) error
Reload refetches the object from the database using the primary keys with an executor.
func (*Revokedtoken) Update ¶
func (o *Revokedtoken) Update(ctx context.Context, exec boil.ContextExecutor, columns boil.Columns) (int64, error)
Update uses an executor to update the Revokedtoken. See boil.Columns.UpdateColumnSet documentation to understand column list inference for updates. Update does not automatically update the record in case of default values. Use .Reload() to refresh the records.
func (*Revokedtoken) Upsert ¶
func (o *Revokedtoken) Upsert(ctx context.Context, exec boil.ContextExecutor, updateColumns, insertColumns boil.Columns) error
Upsert attempts an insert using an executor, and does an update or ignore on conflict. See boil.Columns documentation for how to properly use updateColumns and insertColumns.
type RevokedtokenHook ¶
type RevokedtokenHook func(context.Context, boil.ContextExecutor, *Revokedtoken) error
RevokedtokenHook is the signature for custom Revokedtoken hook methods
type RevokedtokenSlice ¶
type RevokedtokenSlice []*Revokedtoken
RevokedtokenSlice is an alias for a slice of pointers to Revokedtoken. This should almost always be used instead of []Revokedtoken.
func (RevokedtokenSlice) DeleteAll ¶
func (o RevokedtokenSlice) DeleteAll(ctx context.Context, exec boil.ContextExecutor) (int64, error)
DeleteAll deletes all rows in the slice, using an executor.
func (*RevokedtokenSlice) ReloadAll ¶
func (o *RevokedtokenSlice) ReloadAll(ctx context.Context, exec boil.ContextExecutor) error
ReloadAll refetches every row with matching primary key column values and overwrites the original object slice with the newly updated slice.
func (RevokedtokenSlice) UpdateAll ¶
func (o RevokedtokenSlice) UpdateAll(ctx context.Context, exec boil.ContextExecutor, cols M) (int64, error)
UpdateAll updates all rows with the specified column values, using an executor.